@@ -89,12 +89,12 @@ class NexusIOTree:
      *
      * @{
      */
-    TreeTemplate<Node>* read(const std::string& path) const throw (Exception)
+    TreeTemplate<Node>* read(const std::string& path) const
     {
       return dynamic_cast<TreeTemplate<Node>*>(AbstractITree::read(path));
     }
     
-    TreeTemplate<Node>* read(std::istream& in) const throw (Exception);
+    TreeTemplate<Node>* read(std::istream& in) const;
     /** @} */
 
     /**
@@ -102,11 +102,11 @@ class NexusIOTree:
      *
      * @{
      */
-    void write(const Tree& tree, const std::string& path, bool overwrite = true) const throw (Exception)
+    void write(const Tree& tree, const std::string& path, bool overwrite = true) const
     {
       AbstractOTree::write(tree, path, overwrite);
     }
-    void write(const Tree& tree, std::ostream& out) const throw (Exception)
+    void write(const Tree& tree, std::ostream& out) const
     {
       write_(tree, out);
     }
@@ -117,11 +117,11 @@ class NexusIOTree:
      *
      * @{
      */
-    void read(const std::string& path, std::vector<Tree*>& trees) const throw (Exception)
+    void read(const std::string& path, std::vector<Tree*>& trees) const
     {
       AbstractIMultiTree::read(path, trees);
     }
-    void read(std::istream& in, std::vector<Tree*>& trees) const throw (Exception);
+    void read(std::istream& in, std::vector<Tree*>& trees) const;
     /**@}*/
 
     /**
@@ -129,26 +129,26 @@ class NexusIOTree:
      *
      * @{
      */
-    void write(const std::vector<Tree*>& trees, const std::string& path, bool overwrite = true) const throw (Exception)
+    void write(const std::vector<Tree*>& trees, const std::string& path, bool overwrite = true) const
     {
       AbstractOMultiTree::write(trees, path, overwrite);
     }
-    void write(const std::vector<Tree*>& trees, std::ostream& out) const throw (Exception)
+    void write(const std::vector<Tree*>& trees, std::ostream& out) const
     {
       write_(trees, out);
     }
     /** @} */
 
   protected:
-    void write_(const Tree& tree, std::ostream& out) const throw (Exception);
+    void write_(const Tree& tree, std::ostream& out) const;
     
     template<class N>
-    void write_(const TreeTemplate<N>& tree, std::ostream& out) const throw (Exception);
+    void write_(const TreeTemplate<N>& tree, std::ostream& out) const;
 
-    void write_(const std::vector<Tree*>& trees, std::ostream& out) const throw (Exception);
+    void write_(const std::vector<Tree*>& trees, std::ostream& out) const;
     
     template<class N>
-    void write_(const std::vector<TreeTemplate<N>*>& trees, std::ostream& out) const throw (Exception);
+    void write_(const std::vector<TreeTemplate<N>*>& trees, std::ostream& out) const;
 
 };
 
