@@ -71,7 +71,7 @@ public:
       index_(0) {}
 
 public:
-    ConstSiteModelDescription* next() throw (Exception)
+    ConstSiteModelDescription* next()
     {
       if (!hasNext())
         throw Exception("AbstractHomogeneousTreeLikelihood::ConstHomogeneousSiteModelIterator::next(). No more site in the set.");
@@ -121,8 +121,7 @@ public:
     TransitionModel* model,
     DiscreteDistribution* rDist,
     bool checkRooted = true,
-    bool verbose = true)
-  throw (Exception);
+    bool verbose = true);
 
   /**
    * @brief Copy constructor
@@ -148,7 +147,7 @@ private:
              TransitionModel* model,
              DiscreteDistribution* rDist,
              bool checkRooted,
-             bool verbose) throw (Exception);
+             bool verbose);
 
 public:
   /**
@@ -166,7 +165,7 @@ public:
 
   std::string getAlphabetStateAsChar(size_t i) const { return model_->getAlphabetStateAsChar(i); }
 
-  void initialize() throw (Exception);
+  void initialize();
 
   ParameterList getBranchLengthsParameters() const;
 
@@ -200,15 +199,34 @@ public:
    *
    * @{
    */
-  const TransitionModel* getSubstitutionModel() const { return model_; }
-  const TransitionModel* getSubstitutionModel(int nodeId, size_t siteIndex) const throw (NodeNotFoundException) { return model_; }
+  const TransitionModel* getModel() const { return model_; }
+  const TransitionModel* getModel(int nodeId, size_t siteIndex) const { return model_; }
 
-  TransitionModel* getSubstitutionModel() { return model_; }
-  TransitionModel* getSubstitutionModel(int nodeId, size_t siteIndex) throw (NodeNotFoundException) { return model_; }
+  TransitionModel* getModel() { return model_; }
+  TransitionModel* getModel(int nodeId, size_t siteIndex) { return model_; }
 
-  void setSubstitutionModel(TransitionModel* model) throw (Exception);
+  void setModel(TransitionModel* model);
   /** @} */
 
+  /**
+   * @brief Get a SubstitutionModel pointer toward the model associated to this instance, if possible.
+   *
+   * Performs a cast operation on the pointer. Return NULL if cast failed.
+   * @return A SubstitutionModel pointer toward the model associated to this instance.
+   */
+  virtual const SubstitutionModel* getSubstitutionModel() const { return dynamic_cast<const SubstitutionModel*>(model_); }
+  
+  /**
+   * @brief Get a SubstitutionModel pointer toward the model associated to this instance, if possible.
+   *
+   * Performs a cast operation on the pointer. Return NULL if cast failed.
+   * @return A SubstitutionModel pointer toward the model associated to this instance.
+   *
+   * @param nodeId Id of the node
+   * @param siteIndex Position of the site
+   */
+  virtual const SubstitutionModel* getSubstitutionModel(int nodeId, size_t siteIndex) const { return dynamic_cast<const SubstitutionModel*>(model_); }
+
 public:
   // Specific methods:
 
@@ -223,11 +241,11 @@ public:
    * This function apply these parameters to the substitution model,
    * to the rate distribution and to the branch lengths.
    */
-  virtual void applyParameters() throw (Exception);
+  virtual void applyParameters();
 
   virtual void initBranchLengthsParameters(bool verbose = true);
 
-  virtual void setMinimumBranchLength(double minimum) throw (Exception)
+  virtual void setMinimumBranchLength(double minimum)
   {
     if (minimum > maximumBrLen_)
       throw Exception("AbstractHomogeneousTreeLikelihood::setMinimumBranchLength. Minimum branch length sould be lower than the maximum one: " + TextTools::toString(maximumBrLen_));
@@ -237,7 +255,7 @@ public:
     initBranchLengthsParameters();
   }
 
-  virtual void setMaximumBranchLength(double maximum) throw (Exception)
+  virtual void setMaximumBranchLength(double maximum)
   {
     if (maximum < minimumBrLen_)
       throw Exception("AbstractHomogeneousTreeLikelihood::setMaximumBranchLength. Maximum branch length sould be higher than the minimum one: " + TextTools::toString(minimumBrLen_));
