@@ -163,7 +163,7 @@ void UniformizationSubstitutionCount::computeCounts_(double length) const
     for (size_t j = 0; j < nbStates_; j++) {
       for(size_t k = 0; k < nbStates_; k++) {
         counts_[i](j, k) /= P(j, k);
-        if (std::isnan(counts_[i](j, k)) || counts_[i](j, k) < 0.)
+        if (std::isinf(counts_[i](j, k)) || std::isnan(counts_[i](j, k)) || counts_[i](j, k) < 0.)
           counts_[i](j, k) = 0;
         //Weights:
         if (weights_)
@@ -252,7 +252,7 @@ void UniformizationSubstitutionCount::setSubstitutionModel(const SubstitutionMod
 
 /******************************************************************************/
 
-void UniformizationSubstitutionCount::substitutionRegisterHasChanged() throw (Exception)
+void UniformizationSubstitutionCount::substitutionRegisterHasChanged()
 {
   //Check compatiblity between model and substitution register:
   if (model_->getAlphabet()->getAlphabetType() != register_->getAlphabet()->getAlphabetType())
@@ -269,7 +269,7 @@ void UniformizationSubstitutionCount::substitutionRegisterHasChanged() throw (Ex
 
 /******************************************************************************/
 
-void UniformizationSubstitutionCount::weightsHaveChanged() throw (Exception)
+void UniformizationSubstitutionCount::weightsHaveChanged()
 {
   if (weights_->getAlphabet()->getAlphabetType() != register_->getAlphabet()->getAlphabetType())
     throw Exception("UniformizationSubstitutionCount::weightsHaveChanged. Incorrect alphabet type.");
