@@ -40,14 +40,14 @@
 using namespace bpp;
 using namespace std;
 /****************************************************************************************/
-AbstractCodonFitnessSubstitutionModel::AbstractCodonFitnessSubstitutionModel(FrequenciesSet* pfitset, const string& prefix):
-  CodonSubstitutionModel(), AbstractParameterAliasable(prefix), pfitset_(pfitset), fitName_("")
+AbstractCodonFitnessSubstitutionModel::AbstractCodonFitnessSubstitutionModel(FrequenciesSet* pfitset, const GeneticCode* pgencode, const string& prefix):
+  AbstractParameterAliasable(prefix), pfitset_(pfitset), pgencode_(pgencode), fitName_("")
 {
   if (dynamic_cast<CodonFrequenciesSet*>(pfitset) == NULL)
-    throw Exception ("Bad type for fitness parameters"+ pfitset ->getName() );
+    throw Exception ("Bad type for fitness parameters"+ pfitset ->getName());
   fitName_="fit_"+ pfitset_->getNamespace();
   pfitset_->setNamespace(prefix + fitName_);
-  addParameters_(pfitset_->getParameters() );
+  addParameters_(pfitset_->getParameters());
 }
 
 AbstractCodonFitnessSubstitutionModel::~AbstractCodonFitnessSubstitutionModel()
@@ -69,8 +69,10 @@ void AbstractCodonFitnessSubstitutionModel::setFreq(map<int, double>& frequencie
 double AbstractCodonFitnessSubstitutionModel::getCodonsMulRate(size_t i, size_t j) const
 {
   double mu;
+
   double phi_j= pfitset_->getFrequencies() [j];
   double phi_i= pfitset_->getFrequencies() [i];
+  
   if (phi_i == phi_j) mu=1;
   else if (phi_i==0)
     mu=100;
