@@ -116,7 +116,7 @@ bool MixedSubstitutionModelSet::complete()
   size_t nbm = getNumberOfModels();
   for (i = 0; i < nbm; i++)
   {
-    const MixedSubstitutionModel* pSM = dynamic_cast<const MixedSubstitutionModel*>(getTransitionModel(i));
+    const MixedSubstitutionModel* pSM = dynamic_cast<const MixedSubstitutionModel*>(getModel(i));
     if (pSM)
     {
       if (nhn.getNode(i).size() != pSM->getNumberOfModels())
@@ -130,7 +130,7 @@ bool MixedSubstitutionModelSet::complete()
   addEmptyHyperNode();
   for (i = 0; i < nbm; i++)
   {
-    const MixedSubstitutionModel* pSM = dynamic_cast<const MixedSubstitutionModel*>(getTransitionModel(i));
+    const MixedSubstitutionModel* pSM = dynamic_cast<const MixedSubstitutionModel*>(getModel(i));
     if (pSM)
     {
       const MixedSubstitutionModelSet::HyperNode::Node& nd = nhn.getNode(i);
@@ -203,7 +203,7 @@ void MixedSubstitutionModelSet::computeHyperNodesProbabilities()
   MixedSubstitutionModel* pfSM = 0;
   for (fmM = 0; fmM < nbm; fmM++)
   {
-    pfSM = dynamic_cast<MixedSubstitutionModel*>(getTransitionModel(fmM));
+    pfSM = dynamic_cast<MixedSubstitutionModel*>(getModel(fmM));
     if (pfSM != NULL)
       break;
   }
@@ -233,7 +233,7 @@ void MixedSubstitutionModelSet::computeHyperNodesProbabilities()
 
   for (size_t iM = fmM + 1; iM < nbm; iM++)
   {
-    pfSM = dynamic_cast<MixedSubstitutionModel*>(getTransitionModel(iM));
+    pfSM = dynamic_cast<MixedSubstitutionModel*>(getModel(iM));
     if (pfSM != NULL)
     {
       for (size_t nh = 0; nh < nbh; nh++)
@@ -280,7 +280,7 @@ double MixedSubstitutionModelSet::getHyperNodeProbability(const HyperNode& hn) c
   for (size_t fmM = 0; fmM < nbm; fmM++)
   {
     const MixedSubstitutionModelSet::HyperNode::Node& fnd = hn.getNode(fmM);
-    const MixedSubstitutionModel* pfSM = dynamic_cast<const MixedSubstitutionModel*>(getTransitionModel(fmM));
+    const MixedSubstitutionModel* pfSM = dynamic_cast<const MixedSubstitutionModel*>(getModel(fmM));
     if (pfSM != NULL)
     {
       double x = 0;
@@ -308,7 +308,7 @@ MixedSubstitutionModelSet::HyperNode::HyperNode(const MixedSubstitutionModelSet*
 {
   for (size_t i = 0; i < pMSMS->getNumberOfModels(); i++)
   {
-    const MixedSubstitutionModel* pSM = dynamic_cast<const MixedSubstitutionModel*>(pMSMS->getTransitionModel(i));
+    const MixedSubstitutionModel* pSM = dynamic_cast<const MixedSubstitutionModel*>(pMSMS->getModel(i));
     if (!pSM)
       vUnused_.push_back(static_cast<int>(i));
   }
@@ -442,16 +442,14 @@ MixedSubstitutionModelSet::HyperNode::Node& MixedSubstitutionModelSet::HyperNode
 
 bool MixedSubstitutionModelSet::HyperNode::Node::operator<=(const Node& n) const
 {
-  vector<int>::const_iterator it(vNumb_.begin());
   vector<int>::const_iterator it2(n.vNumb_.begin());
 
-  for ( ; it != vNumb_.end(); it++)
+  for (const auto& it : vNumb_)
   {
-    while (it2 != n.vNumb_.end()  && (*it2 < *it))
+    while (it2 != n.vNumb_.end()  && (*it2 < it))
       it2++;
-    if (it2 == n.vNumb_.end() || (*it2 > *it))
+    if (it2 == n.vNumb_.end() || (*it2 > it))
       return false;
-    it++;
   }
   return true;
 }
@@ -463,19 +461,17 @@ bool MixedSubstitutionModelSet::HyperNode::Node::operator>=(const Node& n) const
 
 bool MixedSubstitutionModelSet::HyperNode::Node::intersects(const Node& n) const
 {
-  vector<int>::const_iterator it(vNumb_.begin());
   vector<int>::const_iterator it2(n.vNumb_.begin());
 
-  for ( ; it != vNumb_.end(); it++)
+  for (const auto& it : vNumb_)
   {
-    while (it2 != n.vNumb_.end()  && (*it2 < *it))
+    while (it2 != n.vNumb_.end()  && (*it2 < it))
       it2++;
 
     if (it2 == n.vNumb_.end())
       return false;
-    if (*it2 == *it)
+    if (*it2 == it)
       return true;
-    it++;
   }
   return false;
 }
