@@ -304,21 +304,21 @@ public:
   void clear();
 
   /*
-     *@brief adds a new empty HyperNode to the end of the HyperNodes
+   *@brief adds a new empty HyperNode to the end of the HyperNodes
    * list.
    */
 
   void addEmptyHyperNode();
 
   /*
-     *@brief adds the copy of an HyperNode to the end of the
+   *@brief adds the copy of an HyperNode to the end of the
    * HyperNodes list.
    */
 
   void addHyperNode(const HyperNode& hn);
 
   /*
-     *@brief If necessary, adds a new HyperNode such that all
+   *@brief If necessary, adds a new HyperNode such that all
    *       submodels of the mixture models are at least in an
    *       HyperNode.
    *
@@ -329,13 +329,13 @@ public:
   bool complete();
 
   /*
-     *@brief adds a submodel number to the nMth mixed model of the
+   *@brief adds a submodel number to the nMth mixed model of the
    *  nHth HyperNode of the list (default nH=0). Checks if all the
    *  numbers are valid.
    *
-   ***@param nM number of the mixed model
-   ***@param vnS number of the submodel
-   ***@param nH number of the concerned HyperNode (default the last element of
+   *@param nM number of the mixed model
+   *@param vnS number of the submodel
+   *@param nH number of the concerned HyperNode (default the last element of
    *     the list)
    */
 
@@ -348,7 +348,7 @@ public:
   const HyperNode& getHyperNode(size_t i) const {return *vpHyperNodes_[i]; }
 
   /*
-     *@brief Checks if all the path (ie hypernodes) are exclusive.
+   *@brief Checks if all the path (ie hypernodes) are exclusive.
    *
    */
 
@@ -357,26 +357,25 @@ public:
   void fireParameterChanged(const ParameterList& parameters);
 
   /*
-     *@brief compute the probabilities in all the HyperNodes
+   *@brief compute the probabilities in all the HyperNodes
    *
    */
 
   void computeHyperNodesProbabilities();
 
   /*
-     *@brief computes the probability of an HyperNode, given
-   *     the conditional probabilities of the submodels computed
-   *     from the hypernodes of this MixedSubstitutionModelSet
-   *     object. If the HyperNode does not match the structure of
-   *     allowed by this MixedSubstitutionModelSet, an Exception
-   *     is thrown.
+   *@brief computes the probability of an HyperNode, given the
+   *     conditional probabilities of the submodels computed from the
+   *     hypernodes of this MixedSubstitutionModelSet object. If the
+   *     HyperNode does not match the structure of allowed by this
+   *     MixedSubstitutionModelSet, an Exception is thrown.
    *
-   *     The probability of an HyperNode is the product -- on the
-   *     set of the mixed models -- of the sums of the
-   *     conditional probabilities of the submodels that belon to
-   *     this hypernode for each mixed model.
+   *     The probability of an HyperNode is the product -- on the set
+   *     of the mixed models -- of the sums of the conditional
+   *     probabilities of the submodels that belon to this hypernode
+   *     for each mixed model.
    *
-   ***@param hn the HyperNode which conditional probability is computed.
+   *@param hn the HyperNode which conditional probability is computed.
    */
 
   double getHyperNodeProbability(const HyperNode& hn) const;
