@@ -62,7 +62,7 @@ HKY85::HKY85(
   double piG,
   double piT):
   AbstractParameterAliasable("HKY85."),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "HKY85."),
+  AbstractReversibleNucleotideSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "HKY85."),
   kappa_(kappa), k1_(), k2_(), r_(),
   piA_(piA), piC_(piC), piG_(piG), piT_(piT), piY_(), piR_(),
   theta_(piG + piC), theta1_(piA / (1. - theta_)), theta2_(piG / theta_),
@@ -117,8 +117,9 @@ void HKY85::updateMatrices()
   generator_(1, 3) = kappa_ * piT_;
 	
   // Normalization:
-  r_ = 1. / (2. * (piA_ * piC_ + piC_ * piG_ + piA_ * piT_ + piG_ * piT_ + kappa_ * (piC_ * piT_ + piA_ * piG_)));
-  MatrixTools::scale(generator_, r_);
+  r_ = isScalable()?1. / (2. * (piA_ * piC_ + piC_ * piG_ + piA_ * piT_ + piG_ * piT_ + kappa_ * (piC_ * piT_ + piA_ * piG_))):1;
+
+  setScale(r_);
 	
   // Exchangeability:
   exchangeability_(0,0) = generator_(0,0) / piA_;
