@@ -91,13 +91,12 @@ namespace bpp
  * \endcode
  * for instance.
  * 
- * Reference:
- * - Hobolth A, Christensen O Fm Mailund T, Schierup M H (2007), PLoS_ Genetics_ 3(2) e7.
- * - Yap VB, Speed TP (1995), Journal_ Of Molecular Evolution_ 58(1) 12-18
+ * References:
+ * - Hobolth A, Christensen O Fm Mailund T, Schierup M H (2007), PLoS Genetics 3(2) e7.
+ * - Yap VB, Speed TP (2004), Journal Of Molecular Evolution 58(1) 12-18
  */
   class SSR:
-    public virtual NucleotideSubstitutionModel,
-    public AbstractReversibleSubstitutionModel
+    public AbstractReversibleNucleotideSubstitutionModel
   {
   private:
     double beta_, gamma_, delta_, theta_, piA_, piC_, piG_, piT_;
@@ -111,15 +110,10 @@ namespace bpp
   
     virtual ~SSR() {}
   
-#ifndef NO_VIRTUAL_COV
-    SSR*
-#else
-    Clonable*
-#endif
-    clone() const { return new SSR(*this); }
+    SSR* clone() const { return new SSR(*this); }
   
   public:
-    std::string getName() const { return "Strand Symmetric Reversible"; }
+    std::string getName() const { return "SSR"; }
   
     void updateMatrices();
   
