@@ -52,7 +52,7 @@ using namespace std;
 
 LG08::LG08(const ProteicAlphabet* alpha) :
   AbstractParameterAliasable("LG08."),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "LG08."),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "LG08."),
   freqSet_(0)
 {
   #include "__LG08ExchangeabilityCode"
@@ -63,15 +63,19 @@ LG08::LG08(const ProteicAlphabet* alpha) :
 
 LG08::LG08(const ProteicAlphabet* alpha, ProteinFrequenciesSet* freqSet, bool initFreqs) :
   AbstractParameterAliasable("LG08+F."),
-  AbstractReversibleSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "LG08+F."),
+  AbstractReversibleProteinSubstitutionModel(alpha, new CanonicalStateMap(alpha, false), "LG08+F."),
   freqSet_(freqSet)
 {
   #include "__LG08ExchangeabilityCode"
   #include "__LG08FrequenciesCode"
   freqSet_->setNamespace("LG08+F."+freqSet_->getNamespace());
-  if (initFreqs) freqSet_->setFrequencies(freq_);
-  else freq_ = freqSet_->getFrequencies();
+  if (initFreqs)
+    freqSet_->setFrequencies(freq_);
+  else
+    freq_ = freqSet_->getFrequencies();
+
   addParameters_(freqSet_->getParameters());
+  
   updateMatrices();  
 }
 
