@@ -89,7 +89,6 @@ OptimizationTools::ScaleFunction::ScaleFunction(TreeLikelihood* tl) :
 OptimizationTools::ScaleFunction::~ScaleFunction() {}
 
 void OptimizationTools::ScaleFunction::setParameters(const ParameterList& lambda)
-throw (ParameterNotFoundException, ConstraintException)
 {
   if (lambda.size() != 1)
     throw Exception("OptimizationTools::ScaleFunction::f(). This is a one parameter function!");
@@ -97,7 +96,6 @@ throw (ParameterNotFoundException, ConstraintException)
 }
 
 double OptimizationTools::ScaleFunction::getValue() const
-throw (ParameterException)
 {
   // Scale the tree:
   ParameterList brLen = brLen_;
@@ -125,7 +123,6 @@ unsigned int OptimizationTools::optimizeTreeScale(
   OutputStream* messageHandler,
   OutputStream* profiler,
   unsigned int verbose)
-throw (Exception)
 {
   ScaleFunction sf(tl);
   BrentOneDimension bod(&sf);
@@ -160,7 +157,6 @@ unsigned int OptimizationTools::optimizeNumericalParameters(
   unsigned int verbose,
   const std::string& optMethodDeriv,
   const std::string& optMethodModel)
-throw (Exception)
 {
   DerivableSecondOrder* f = tl;
   ParameterList pl = parameters;
@@ -264,7 +260,6 @@ unsigned int OptimizationTools::optimizeNumericalParameters2(
   bool useClock,
   unsigned int verbose,
   const std::string& optMethodDeriv)
-throw (Exception)
 {
   DerivableSecondOrder* f = tl;
   ParameterList pl = parameters;
@@ -355,7 +350,6 @@ unsigned int OptimizationTools::optimizeBranchLengthsParameters(
   OutputStream* profiler,
   unsigned int verbose,
   const std::string& optMethodDeriv)
-throw (Exception)
 {
   // Build optimizer:
   Optimizer* optimizer = 0;
@@ -414,7 +408,6 @@ unsigned int OptimizationTools::optimizeNumericalParametersWithGlobalClock(
   OutputStream* profiler,
   unsigned int verbose,
   const std::string& optMethodDeriv)
-throw (Exception)
 {
   AbstractNumericalDerivative* fun = 0;
 
@@ -483,7 +476,6 @@ unsigned int OptimizationTools::optimizeNumericalParametersWithGlobalClock2(
   OutputStream* profiler,
   unsigned int verbose,
   const std::string& optMethodDeriv)
-throw (Exception)
 {
   AbstractNumericalDerivative* fun = 0;
 
@@ -576,7 +568,6 @@ NNIHomogeneousTreeLikelihood* OptimizationTools::optimizeTreeNNI(
   const std::string& optMethodDeriv,
   unsigned int nStep,
   const std::string& nniMethod)
-throw (Exception)
 {
   // Roughly optimize parameter
   if (optimizeNumFirst)
@@ -608,7 +599,6 @@ NNIHomogeneousTreeLikelihood* OptimizationTools::optimizeTreeNNI2(
   unsigned int verbose,
   const std::string& optMethodDeriv,
   const std::string& nniMethod)
-throw (Exception)
 {
   // Roughly optimize parameter
   if (optimizeNumFirst)
@@ -648,7 +638,7 @@ DistanceMatrix* OptimizationTools::estimateDistanceMatrix(
   DistanceEstimation& estimationMethod,
   const ParameterList& parametersToIgnore,
   const std::string& param,
-  unsigned int verbose) throw (Exception)
+  unsigned int verbose)
 {
   if (param != DISTANCEMETHOD_PAIRWISE && param != DISTANCEMETHOD_INIT)
     throw Exception("OptimizationTools::estimateDistanceMatrix. Invalid option param=" + param + ".");
@@ -656,7 +646,7 @@ DistanceMatrix* OptimizationTools::estimateDistanceMatrix(
   estimationMethod.setVerbose(verbose);
   if (param == DISTANCEMETHOD_PAIRWISE)
   {
-    ParameterList tmp = estimationMethod.getSubstitutionModel().getIndependentParameters();
+    ParameterList tmp = estimationMethod.getModel().getIndependentParameters();
     tmp.addParameters(estimationMethod.getRateDistribution().getIndependentParameters());
     tmp.deleteParameters(parametersToIgnore.getParameterNames());
     estimationMethod.setAdditionalParameters(tmp);
@@ -684,13 +674,13 @@ TreeTemplate<Node>* OptimizationTools::buildDistanceTree(
   unsigned int tlEvalMax,
   OutputStream* profiler,
   OutputStream* messenger,
-  unsigned int verbose) throw (Exception)
+  unsigned int verbose)
 {
   estimationMethod.resetAdditionalParameters();
   estimationMethod.setVerbose(verbose);
   if (param == DISTANCEMETHOD_PAIRWISE)
   {
-    ParameterList tmp = estimationMethod.getSubstitutionModel().getIndependentParameters();
+    ParameterList tmp = estimationMethod.getModel().getIndependentParameters();
     tmp.addParameters(estimationMethod.getRateDistribution().getIndependentParameters());
     tmp.deleteParameters(parametersToIgnore.getParameterNames());
     estimationMethod.setAdditionalParameters(tmp);
@@ -741,7 +731,7 @@ TreeTemplate<Node>* OptimizationTools::buildDistanceTree(
       break;  // Ends here.
 
     // Now, re-estimate parameters:
-    unique_ptr<TransitionModel> model(estimationMethod.getSubstitutionModel().clone());
+    unique_ptr<TransitionModel> model(estimationMethod.getModel().clone());
     unique_ptr<DiscreteDistribution> rdist(estimationMethod.getRateDistribution().clone());
     DRHomogeneousTreeLikelihood tl(*tree,
         *estimationMethod.getData(),
